@@ -1,6 +1,6 @@
 ############################################################
 #
-#   $Id: Simple.pm 518 2006-05-29 11:32:23Z nicolaw $
+#   $Id: Simple.pm,v 1.3 2006/01/01 23:12:28 nicolaw Exp $
 #   Colloquy::Bot::Simple - Simple robot interface for Colloquy
 #
 #   Copyright 2006 Nicola Worthington
@@ -25,24 +25,21 @@ package Colloquy::Bot::Simple;
 use base qw(Chatbot::TalkerBot);
 
 use strict;
-no warnings qw(redefine);
-
 use Exporter;
 use Carp qw(croak cluck carp confess);
-use Parse::Colloquy::Bot qw(:all);
-
 use vars qw(@EXPORT @EXPORT_OK $VERSION);
-
 @EXPORT = qw(&connect_through_firewall &connect_directly &daemonize);
 @EXPORT_OK = qw(TB_TRACE TB_LOG);
 
-$VERSION = '1.08' || sprintf('%d', q$Revision: 518 $ =~ /(\d+)/g);
+$VERSION = sprintf('%d.%02d', q$Revision: 1.3 $ =~ /(\d+)/g);
 
 sub TB_LOG { Chatbot::TalkerBot::TB_TRACE(@_); }
 sub TB_TRACE { Chatbot::TalkerBot::TB_TRACE(@_); }
 
 sub listenLoop {
 	my $self = shift;
+	my $matchre = '^(?:TELL|LISTTALK|TALK|OBSERVED \S+ (?:EMOTE @|TALK)) (\S{1,10})\s*[@%:>]?(.*)$';
+	#my $matchre = shift || die("You must supply a match string/regexp");
 	my $callback = shift;
 	my $interrupt = shift;
 	
@@ -65,14 +62,29 @@ sub listenLoop {
 		s/[\n\r]//g;
 		
 		# only pay any attention to that regular expression
-		if ($self->{'AnyCommands'} == 1) {
-			my $args = Parse::Colloquy::Bot::parse_line($_);
-			$args->{alarm} = 0;
+		if (($self->{'AnyCommands'} == 1) && (m/$matchre/)) {
+			my $person = $1;
+			my $text = $2;
 
-			TB_LOG("Attending: <$args->{msgtype}> = <$args->{text}>");
+			my $list = _is_list($text);
+			if ($list && $list =~ /^\%(.+)$/) {
+				$text =~ s/\{$1\}\s*$//;
+			}
+
+			my ($msgtype) = $_ =~ /^([A-Z]+)\s+/;
+
+			TB_LOG("Attending: <$person> says <$text>");
 			$self->{'lines_in'} += 1;
+			my ($command, @args) = split(/ /, $text);
 
-			$STOPLOOP = $callback->($self, %{$args});
+			$STOPLOOP = $callback->($self, 
+						person => $person,
+						command => $command,
+						list => $list,
+						msgtype => $msgtype,
+						raw => $_,
+						args => \@args,
+					);
 		}
 		
 		# command processing done, turn interrupts back on
@@ -107,13 +119,13 @@ sub new {
 	my $talker = $class->SUPER::new($socket, {
 			Username => $self->{username},
 			Password => $self->{password},
-			UsernameResponse => $self->{usernameresponse} || '<USER> <PASS>',
-			UsernamePrompt => $self->{usernameprompt} || 'HELLO colloquy',
-			PasswordPrompt => $self->{passwordprompt} || '',
-			PasswordResponse => $self->{passwordresponse} || '',
-			LoginSuccess => $self->{loginsuccess} || 'MARK ---',
-			LoginFail => $self->{loginfail} || 'Incorrect login',
-			#NoCommands => 1,
+			UsernameResponse => '<USER> <PASS>',
+			UsernamePrompt => 'HELLO colloquy',
+			PasswordPrompt => '',
+			PasswordResponse => '',
+			LoginSuccess => 'MARK ---',
+			LoginFail => 'Incorrect login',
+			NoCommands => 1,
 		});
 
 	return $talker;
@@ -121,7 +133,7 @@ sub new {
 
 sub _is_list {
 	local $_ = shift || '';
-	if (/^LIST.+\{(\w+?)\}\s*$/) {
+	if (/^LISTTALK\s+.+\{(\w+?)\}\s*$/) {
 		return '%'.$1;
 	} elsif (/^OBSERVED\s+(\S+)\s+/) {
 		return '@'.$1;
@@ -273,7 +285,7 @@ Colloquy::Bot::Simple - Simple robot interface for Colloquy
 
 =head1 DESCRIPTION
 
-A very simple robot interface to connect and interact with a Colloquy talker,
+A very simple robot interface to connect and interect with a Colloquy talker,
 based upon Chatbot::TalkerBot.
 
 =head1 METHODS
@@ -296,11 +308,11 @@ Write some decent POD.
 
 =head1 SEE ALSO
 
-L<Chatbot::TalkerBot>, L<Parse::Colloquy::Bot>, L<Bundle::Colloquy::BotBot2>
+L<Chatbot::TalkerBot>
 
 =head1 VERSION
 
-$Id: Simple.pm 518 2006-05-29 11:32:23Z nicolaw $
+$Id: Simple.pm,v 1.3 2006/01/01 23:12:28 nicolaw Exp $
 
 =head1 AUTHOR
 
